@@ -12,6 +12,7 @@ from .hlt_med_record import HltMedRecord
 from .hlt_mkab import HltMkab, Gender
 from .hlt_reason_care import HltReasonCare
 from .hlt_representative_mkab import HltRepresentativeMkab
+from .hlt_smtap import HltSmTap
 from .hlt_tap import HltTap
 from .hlt_type_call_doctor import HltTypeCallDoctor
 from .hlt_uchastok import HltUchastok
@@ -41,6 +42,7 @@ from .oms_okved import OmsOkved
 from .oms_organisation import OmsOrganisation
 from .oms_prvd import OmsPrvd
 from .oms_prvs import OmsPrvs
+from .oms_service_medical import OmsServiceMedical
 from .oms_smo import OmsSmo
 from .oms_type_doc import OmsTypedoc
 from .x_user import XUser
